#ifndef NT2_INCLUDE_FUNCTIONS_SCALAR_IS_NOT_EQUAL_WITH_EQUAL_NANS_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_SCALAR_IS_NOT_EQUAL_WITH_EQUAL_NANS_HPP_INCLUDED

#include <nt2/predicates/include/functions/scalar/is_not_equal_with_equal_nans.hpp>

#endif
